Learn R Programming

heemod (version 0.9.1)

combine_probs: Combine Probabilities

Description

Given several independent probabilities of an event, return the final probability of the event.

Usage

combine_probs(...)

Arguments

...
Probability vectors.

Value

A probability vector.

Details

This function is only correct if the probabilities are independent!

Examples

Run this code

(p1 <- runif(5))
(p2 <- runif(5))
combine_probs(p1, p2)

Run the code above in your browser using DataLab