Learn R Programming

heemod (version 0.4.0)

gather_model_info: Gather Information for Running a Model From Tabular Data

Description

Gather Information for Running a Model From Tabular Data

Usage

gather_model_info(base_dir, ref_file)

Arguments

base_dir
Directory where the files are located.
ref_file
Name of the reference file.

Value

A list with elements:
  • models (of type uneval_model, created by create_model_list_from_tabular)
  • param_info
  • output_dir where to store output files, if specified
  • demographic_file a table for demographic analysis
  • model_options a list of model options.