Learn R Programming

heemod (version 0.9.1)

interp_heemod: Interpolate Lazy Dots

Description

Sequentially interpolates lazy dots, optionally using external references.

Usage

interp_heemod(x, ...)

# S3 method for default interp_heemod(x, more = NULL, ...)

# S3 method for uneval_matrix interp_heemod(x, ...)

# S3 method for state interp_heemod(x, ...)

# S3 method for part_surv interp_heemod(x, ...)

# S3 method for uneval_state_list interp_heemod(x, ...)

Arguments

x
A parameter, transition matrix or state list object.
...
Addition parameters passed to methods.
more
A list of expressions.

Value

An interpolated lazy dots object.

Details

The interpolation is sequential: the second dot is interpolated using the first, the third using the interpolated first two, and so on.