a list of matrices of flexsurvreg
objects, for example the first element of the output of
survival_from_data.
state_names
names of states of the model
Value
a tibble of partitioned survival objects, similar to the
original tibble of survival fits, with all the columns
except type and fit, and a new column part_surv.
Details
surv_inputs is a tibble with columns type (PFS
or OS, not case sensitive), treatment, set_name (for
data subsets), dist (for survival distribution
assumptions), fit (for the fitted survival object) and
set_def (how the subset of data was defined, just to
keep it around)