Learn R Programming

heemod (version 0.9.0)

define_calibration_fn: Define Calibration Function

Description

Define a function to be passed to the fn_values argument of calibrate_model().

Usage

define_calibration_fn(type, strategy_names, element_names, cycles,
  groups = NULL, aggreg_fn = sum)

Arguments

type
Type of model values (count or value).
strategy_names
Names of strategies.
element_names
Names of states (for counts) or of state values (for values).
cycles
Cycles of interest.
groups
Optional grouping of values (values in a same group have the same groups).
aggreg_fn
A function to aggregate values in a same group.

Value

A numeric vector.

Examples

Run this code
example("run_model")

f <- define_calibration_fn(
  type = c("count", "count", "value"),
  strategy_names = c("I", "I", "II"),
  element_names = c("A", "B", "ly"),
  cycles = c(3, 5, 9),
  groups = c(1, 1, 2),
  aggreg_fn = mean
)

f(res2)

Run the code above in your browser using DataLab