Learn R Programming

heemod (version 0.9.1)

who_mortality: Use WHO Mortality Rate

Description

Returns age and sex-specific mortality probabilities for a given country.

Usage

get_who_mr_memo(age, sex = NULL, region = NULL, country = NULL,
  year = "latest", local = FALSE)

get_who_mr(age, sex = NULL, region = NULL, country = NULL, year = "latest", local = FALSE)

Arguments

age
age as a continuous variable.
sex
sex as "FMLE"-"MLE", 0-1 (male = 0, female = 1) or 1-2 (male = 1, female = 2).
region
Region code. Assumed NULL if provided along with country.
country
Country code (see details).
year
Use data from that year. Defaults to "latest".
local
Fetch mortality data from package cached data?

Value

This function should be used within define_transition() or define_parameters().

Details

Locally cached data is used in case of connection problems, of if local = TRUE. For memory space reasons local data is only available for WHO high-income countries, and only for the latest year.

The results of get_who_mr are memoised for options("heemod.memotime") (default: 1 hour) to increase resampling performance.

Examples

Run this code

define_transition(
  C, get_who_mr(age = 50 + markov_cycle, sex = "FMLE", country = "FRA"),
  0, 1
)

Run the code above in your browser using DataLab